#!/usr/local/bin/perl
# * ====================================================================
# * Copyright (c) 1995,1996, ISIS/JRC.  All rights reserved.
# *
# * This product was developed within the Institute for Safety, Informatics
# * and Systems of the Joint Research Centre of the European Commission.
# *
# * More information about us; and this software product can
# * be found on http://www.jrc.it.
# *
# * With this file you should have received a file called 'License'.
# *
# * Redistribution and use in source and binary forms, with or without
# * modification, are permitted provided that the following conditions
# * are met:
# *
# * 1. Redistributions of source code must retain the above copyright
# *    notice, this list of conditions and the following disclaimer.
# *
# * 2. Redistributions in binary form must reproduce the above copyright
# *    notice, this list of conditions and the following disclaimer in
# *    the documentation and/or other materials provided with the
# *    distribution.
# *
# * 3. All materials mentioning features or use of this
# *    software must display the following acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * 4. The name of the Copyright holder must not be used to
# *    endorse or promote products derived from this software without
# *    prior written permission.
# *
# * 5. Redistributions of any form whatsoever must retain the following
# *    acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * THIS SOFTWARE IS PROVIDED BY ISIS/JRC ``AS IS'' AND ANY
# * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ISIS/JRC OR
# * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
# * OF THE POSSIBILITY OF SUCH DAMAGE.
# * ====================================================================
#


package ASN1::Standard;


# The standard definitions for ASN1
# 
# This could be extended to include the 
# definitions for UTCTime, GeneralString, etc.
# but for brevities sake have been included
# in the parser. They are mentioned in the
# spec.

# Not used in structure definitions directly, use external attribute
# this structure is parsed internally with decode_external
%EXTERNAL = (tag=>$BER::EXTERNAL, class=>$BER::UNIVERSAL, encoded_as=>$BER::EXTERNAL, seq=>[
      {label=>'direct-reference', tag=>$BER::OID, class=>$BER::UNIVERSAL, encoded_as=>$BER::OID, optional=>1},
      {label=>'indirect-reference', tag=>$BER::INTEGER, class=>$BER::UNIVERSAL, encoded_as=>$BER::INTEGER, optional=>1},
      {label=>'data-value-descriptor', tag=>$BER::ODSC, class=>$BER::UNIVERSAL, encoded_as=>$BER::ODSC, optional=>1},
      {label=>'encoding', choice=>[
         {label=>'single-ASN1-type', tag=>0, class=>$BER::CONTEXT},     # decoded in decode_external, misses encoded_as
         {label=>'octet-aligned', tag=>1, class=>$BER::CONTEXT, encoded_as=>$BER::OCTET_STR, },
         {label=>'arbitrary', tag=>2, class=>$BER::CONTEXT, encoded_as=>$BER::BIT_STR}
      ]}
   ]);

%ANY = (choice=>[
      {label=>'boolean', tag=>$BER::BOOLEAN, class=>$BER::UNIVERSAL, encoded_as=>$BER::BOOLEAN},
      {label=>'integer', tag=>$BER::INTEGER, class=>$BER::UNIVERSAL, encoded_as=>$BER::INTEGER},
      {label=>'bit_string', tag=>$BER::BIT_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::BIT_STR},
      {label=>'octet_string', tag=>$BER::OCTET_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::OCTET_STR},
      {label=>'null', tag=>$BER::NULL, class=>$BER::UNIVERSAL, encoded_as=>$BER::NULL},
      {label=>'oid', tag=>$BER::OID, class=>$BER::UNIVERSAL, encoded_as=>$BER::OID},
      {label=>'odsc', tag=>$BER::ODSC, class=>$BER::UNIVERSAL, encoded_as=>$BER::ODSC},
      {label=>'external', tag=>$BER::EXTERNAL, class=>$BER::UNIVERSAL, encoded_as=>$BER::EXTERNAL},
      {label=>'real', tag=>$BER::REAL, class=>$BER::UNIVERSAL, encoded_as=>$BER::REAL},
      {label=>'enumerated', tag=>$BER::ENUMERATED, class=>$BER::UNIVERSAL, encoded_as=>$BER::ENUMERATED},
      {label=>'embedded_pdv', tag=>$BER::EMBED_PDV, class=>$BER::UNIVERSAL, encoded_as=>$BER::EMBED_PDV},
      {label=>'utf8_string', tag=>$BER::UTF8STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::UTF8STR},
      {label=>'sequence', tag=>$BER::SEQUENCE, class=>$BER::UNIVERSAL, encoded_as=>$BER::SEQUENCE},
      {label=>'set', tag=>$BER::SET, class=>$BER::UNIVERSAL, encoded_as=>$BER::SET},
      {label=>'numeric_string', tag=>$BER::NUM_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::NUM_STR},
      {label=>'printable_string', tag=>$BER::PRN_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::PRN_STR},
      {label=>'teletex', tag=>$BER::TELETEX, class=>$BER::UNIVERSAL, encoded_as=>$BER::TELETEX},
      {label=>'videotex', tag=>$BER::VIDEOTEX, class=>$BER::UNIVERSAL, encoded_as=>$BER::VIDEOTEX},
      {label=>'ia5_string', tag=>$BER::IA5_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::IA5_STR},
      {label=>'utc_time', tag=>$BER::UTCTIME, class=>$BER::UNIVERSAL, encoded_as=>$BER::UTCTIME},
      {label=>'general_time', tag=>$BER::GENTIME, class=>$BER::UNIVERSAL, encoded_as=>$BER::GENTIME},
      {label=>'graphic_string', tag=>$BER::GRP_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::GRP_STR},
      {label=>'visible_string', tag=>$BER::VIS_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::VIS_STR},
      {label=>'generic_string', tag=>$BER::GEN_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::GEN_STR},
      {label=>'universal_string', tag=>$BER::UNI_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::UNI_STR},
      {label=>'basic_multilingual_plain_string', tag=>$BER::BMP_STR, class=>$BER::UNIVERSAL, encoded_as=>$BER::BMP_STR}
   ]);

1;
